==> haskell-uuid-types-1.0.3-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-C70jVBzardLFMfav9eGqfw
key: uuid-types-1.0.3-C70jVBzardLFMfav9eGqfw
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder
abi: c8c92b90f840b05e255cb21231f7b398
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-C70jVBzardLFMfav9eGqfw
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy=0960747f6d33db66637f40f842025f18
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-types-1.0.3-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-5JdJbSGeEmt9gCOhL7Eqyj
key: uuid-types-1.0.3-5JdJbSGeEmt9gCOhL7Eqyj
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder
abi: fde37d7b71b57d4a69e6a73388a073de
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-5JdJbSGeEmt9gCOhL7Eqyj
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    hashable-1.2.7.0-LNZUQuuTAXDAhrIFkkeiYc
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             hashable-1.2.7.0-LNZUQuuTAXDAhrIFkkeiYc=c4d94c55b0f818097c80d373d8b40893
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
